@@ -1,12 +1,6 @@
-"""SCons.Executor
-
-A module for executing actions with specific lists of target and source
-Nodes.
-
-"""
-
+# MIT License
 #
-# Copyright (c) 2001 - 2019 The SCons Foundation
+# Copyright The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -26,20 +20,19 @@ Nodes.
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-from __future__ import print_function
 
-__revision__ = "/src/script/src/engine/SCons/Executor.py none 2019-12-16 19:06:27 none"
+"""Execute actions with specific lists of target and source Nodes."""
 
 import collections
 
-import SCons.Debug
-from SCons.Debug import logInstanceCreation
 import SCons.Errors
 import SCons.Memoize
 import SCons.Util
-from SCons.compat import with_metaclass, NoSlotsPyPy
+from SCons.compat import NoSlotsPyPy
+import SCons.Debug
+from SCons.Debug import logInstanceCreation
 
-class Batch(object):
+class Batch:
     """Remembers exact association between targets
     and sources of executor."""
 
@@ -70,10 +63,6 @@ class TSList(collections.UserList):
     def __getitem__(self, i):
         nl = self.func()
         return nl[i]
-    def __getslice__(self, i, j):
-        nl = self.func()
-        i, j = max(i, 0), max(j, 0)
-        return nl[i:j]
     def __str__(self):
         nl = self.func()
         return str(nl)
@@ -81,7 +70,7 @@ class TSList(collections.UserList):
         nl = self.func()
         return repr(nl)
 
-class TSObject(object):
+class TSObject:
     """A class that implements $TARGET or $SOURCE expansions by wrapping
     an Executor method.
     """
@@ -156,7 +145,7 @@ _execute_str_map = {0 : execute_null_str,
                     1 : execute_actions_str}
 
 
-class Executor(object, with_metaclass(NoSlotsPyPy)):
+class Executor(object, metaclass=NoSlotsPyPy):
     """A class for controlling instances of executing an action.
 
     This largely exists to hold a single association of an action,
@@ -281,10 +270,8 @@ class Executor(object, with_metaclass(NoSlotsPyPy)):
         return self.get_lvars()[targets_string]
 
     def set_action_list(self, action):
-        import SCons.Util
         if not SCons.Util.is_List(action):
             if not action:
-                import SCons.Errors
                 raise SCons.Errors.UserError("Executor must have an action.")
             action = [action]
         self.action_list = action
@@ -589,7 +576,7 @@ def get_NullEnvironment():
         nullenv = NullEnvironment()
     return nullenv
 
-class Null(object, with_metaclass(NoSlotsPyPy)):
+class Null(object, metaclass=NoSlotsPyPy):
     """A null Executor, with a null build Environment, that does
     nothing when the rest of the methods call it.
 
