@@ -1,17 +1,6 @@
-# -*- coding: utf-8; -*-
-
-"""SCons.Tool.clang
-
-Tool-specific initialization for clang.
-
-There normally shouldn't be any need to import this module directly.
-It will usually be imported through the generic SCons.Tool.Tool()
-selection method.
-
-"""
-
+# MIT License
 #
-# Copyright (c) 2001 - 2019 The SCons Foundation
+# Copyright The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,9 +20,13 @@ selection method.
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
 
-# __revision__ = "/src/script/src/engine/SCons/Tool/clang.py none 2019-12-16 19:06:27 none"
+"""Tool-specific initialization for clang.
+
+There normally shouldn't be any need to import this module directly.
+It will usually be imported through the generic SCons.Tool.Tool()
+selection method.
+"""
 
 # Based on SCons/Tool/gcc.py by Paweł Tomulik 2014 as a separate tool.
 # Brought into the SCons mainline by Russel Winder 2017.
@@ -41,11 +34,11 @@ selection method.
 import os
 import re
 import subprocess
-import sys
 
 import SCons.Util
 import SCons.Tool.cc
 from SCons.Tool.clangCommon import get_clang_install_dirs
+from SCons.Tool.MSCommon import msvc_setup_env_once
 
 
 compilers = ['clang']
@@ -62,6 +55,10 @@ def generate(env):
             clang_bin_dir = os.path.dirname(clang)
             env.AppendENVPath('PATH', clang_bin_dir)
 
+            # Set-up ms tools paths
+            msvc_setup_env_once(env)
+
+
     env['CC'] = env.Detect(compilers) or 'clang'
     if env['PLATFORM'] in ['cygwin', 'win32']:
         env['SHCCFLAGS'] = SCons.Util.CLVar('$CCFLAGS')
@@ -79,8 +76,7 @@ def generate(env):
         # clang -dumpversion is of no use
         with pipe.stdout:
             line = pipe.stdout.readline()
-        if sys.version_info[0] > 2:
-            line = line.decode()
+        line = line.decode()
         match = re.search(r'clang +version +([0-9]+(?:\.[0-9]+)+)', line)
         if match:
             env['CCVERSION'] = match.group(1)
