@@ -1,15 +1,6 @@
-"""SCons.Tool.gcc
-
-Tool-specific initialization for MinGW (http://www.mingw.org/)
-
-There normally shouldn't be any need to import this module directly.
-It will usually be imported through the generic SCons.Tool.Tool()
-selection method.
-
-"""
-
+# MIT License
 #
-# Copyright (c) 2001 - 2019 The SCons Foundation
+# Copyright The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -29,9 +20,16 @@ selection method.
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
 
-__revision__ = "/src/script/src/engine/SCons/Tool/mingw.py none 2019-12-17 02:06:27 none"
+"""SCons.Tool.gcc
+
+Tool-specific initialization for MinGW (http://www.mingw.org/)
+
+There normally shouldn't be any need to import this module directly.
+It will usually be imported through the generic SCons.Tool.Tool()
+selection method.
+
+"""
 
 import os
 import os.path
@@ -50,6 +48,7 @@ mingw_paths = [
     r'C:\msys64\mingw64\bin',
     r'C:\cygwin\bin',
     r'C:\msys',
+    r'C:\ProgramData\chocolatey\lib\mingw\tools\install\mingw64\bin'
 ]
 
 
@@ -143,6 +142,11 @@ def generate(env):
     mingw = SCons.Tool.find_program_path(env, key_program, default_paths=mingw_paths)
     if mingw:
         mingw_bin_dir = os.path.dirname(mingw)
+
+        # Adjust path if we found it in a chocolatey install
+        if mingw_bin_dir == r'C:\ProgramData\chocolatey\bin':
+            mingw_bin_dir = r'C:\ProgramData\chocolatey\lib\mingw\tools\install\mingw64\bin'
+
         env.AppendENVPath('PATH', mingw_bin_dir)
 
     # Most of mingw is the same as gcc and friends...
@@ -163,21 +167,20 @@ def generate(env):
     env['SHCXXFLAGS'] = SCons.Util.CLVar('$CXXFLAGS')
     env['SHLINKFLAGS'] = SCons.Util.CLVar('$LINKFLAGS -shared')
     env['SHLINKCOM'] = shlib_action
+    env['SHLINKCOMSTR'] = shlib_generator
     env['LDMODULECOM'] = ldmodule_action
     env.Append(SHLIBEMITTER=[shlib_emitter])
     env.Append(LDMODULEEMITTER=[shlib_emitter])
     env['AS'] = 'as'
 
-    env['WIN32DEFPREFIX'] = ''
-    env['WIN32DEFSUFFIX'] = '.def'
-    env['WINDOWSDEFPREFIX'] = '${WIN32DEFPREFIX}'
-    env['WINDOWSDEFSUFFIX'] = '${WIN32DEFSUFFIX}'
+    env['WINDOWSDEFPREFIX'] = ''
+    env['WINDOWSDEFSUFFIX'] = '.def'
 
     env['SHOBJSUFFIX'] = '.o'
     env['STATIC_AND_SHARED_OBJECTS_ARE_THE_SAME'] = 1
     env['RC'] = 'windres'
     env['RCFLAGS'] = SCons.Util.CLVar('')
-    env['RCINCFLAGS'] = '$( ${_concat(RCINCPREFIX, CPPPATH, RCINCSUFFIX, __env__, RDirs, TARGET, SOURCE)} $)'
+    env['RCINCFLAGS'] = '${_concat(RCINCPREFIX, CPPPATH, RCINCSUFFIX, __env__, RDirs, TARGET, SOURCE, affect_signature=False)}'
     env['RCINCPREFIX'] = '--include-dir '
     env['RCINCSUFFIX'] = ''
     env['RCCOM'] = '$RC $_CPPDEFFLAGS $RCINCFLAGS ${RCINCPREFIX} ${SOURCE.dir} $RCFLAGS -i $SOURCE -o $TARGET'
@@ -189,6 +192,16 @@ def generate(env):
     env['LIBSUFFIX'] = '.a'
     env['PROGSUFFIX'] = '.exe'
 
+    # Handle new versioned shared library logic
+    env['_SHLIBSUFFIX'] = '$SHLIBSUFFIX'
+    env["SHLIBPREFIX"] = ""
+
+    # Disable creating symlinks for versioned shared library.
+    env['SHLIBNOVERSIONSYMLINKS'] = True
+    env['LDMODULENOVERSIONSYMLINKS'] = True
+    env['IMPLIBNOVERSIONSYMLINKS'] = True
+
+
 
 def exists(env):
     mingw = SCons.Tool.find_program_path(env, key_program, default_paths=mingw_paths)
