@@ -4,7 +4,7 @@ The rpm packager.
 """
 
 #
-# Copyright (c) 2001 - 2019 The SCons Foundation
+# __COPYRIGHT__
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -25,9 +25,8 @@ The rpm packager.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "/src/script/src/engine/SCons/Tool/packaging/rpm.py none 2019-12-17 02:06:27 none"
+__revision__ = "__FILE__ __REVISION__ __DATE__ __DEVELOPER__"
 
-import os
 
 import SCons.Builder
 import SCons.Tool.rpmutils
@@ -284,7 +283,7 @@ def build_specfile_filesection(spec, files):
     for file in files:
         # build the tagset
         tags = {}
-        for k in list(supported_tags.keys()):
+        for k in supported_tags.keys():
             try:
                 v = file.GetTag(k)
                 if v:
@@ -301,22 +300,25 @@ def build_specfile_filesection(spec, files):
 
     return str
 
-class SimpleTagCompiler(object):
-    """ This class is a simple string substition utility:
-    the replacement specfication is stored in the tagset dictionary, something
-    like:
-     { "abc"  : "cdef %s ",
-       "abc_" : "cdef %s %s" }
+class SimpleTagCompiler:
+    """ Compile RPM tags by doing simple string substitution.
 
-    the compile function gets a value dictionary, which may look like:
-    { "abc"    : "ghij",
-      "abc_gh" : "ij" }
+    The replacement specfication is stored in the *tagset* dictionary,
+    something like::
+
+      {"abc" : "cdef %s ", "abc_": "cdef %s %s"}
+
+    The :func:`compile` function gets a value dictionary, which may look like::
+
+      {"abc": "ghij", "abc_gh": "ij"}
+
+    The resulting string will be::
+
+      "cdef ghij cdef gh ij"
 
-    The resulting string will be:
-     "cdef ghij cdef gh ij"
     """
     def __init__(self, tagset, mandatory=1):
-        self.tagset    = tagset
+        self.tagset = tagset
         self.mandatory = mandatory
 
     def compile(self, values):
