@@ -1,7 +1,7 @@
 __version__="4.3.0"
 __copyright__="Copyright (c) 2001 - 2021 The SCons Foundation"
 __developer__="_reproducible"
-__date__="Fri, 19 Nov 2021 04:03:26 +0000"
+__date__="Wed, 15 Dec 2021 05:30:09 +0000"
 __buildsys__="_reproducible"
 __revision__=""
 __build__=""
